const localizationContainer = new (class {
    constructor() {
        this.modelDecorators = new Array();
    }
    addModelDecorator(target, data, name) {
        this.modelDecorators.push({ target: target, config: data, name: name });
    }
    getModelDecorator(target, name) {
        if (typeof (target) == "string")
            return this.modelDecorators.filter(t => t.config == target && t.name == name)[0];
        else
            return this.modelDecorators.filter(t => t.target == target && t.name == name)[0];
    }
})();

const MultiLingualData = new (class {
    constructor() {
        this.data = {};
        this.listners = {};
        this.incrementCount = 0;
        this.current = {};
    }
    addOrUpdate(key, data) {
        this.current = this.data[key] = data;
    }
    contains(key) {
        return this.data[key] !== undefined;
    }
    get(path) {
        if (!this.data)
            return;
        var currentObject = this.data;
        let props = path.split(".");
        for (let prop of props) {
            currentObject = currentObject[prop];
            if (currentObject === undefined)
                break;
        }
        return currentObject === undefined ? '' : currentObject;
    }
    getName(component) {
        let decoratorConfig = localizationContainer.getModelDecorator(component, 'multilingual');
        return decoratorConfig ? decoratorConfig.config : '';
    }
    clearAll() {
        Object.keys(this.data).forEach(t => delete this.data[t]);
        this.data = {};
    }
    subscribe(func) {
        this.incrementCount = this.incrementCount + 1;
        this.listners[this.incrementCount] = func;
        return this.incrementCount;
    }
    unsubscribe(key) {
        delete this.listners[key];
    }
});

function multilingual(keyName) {
    return function (target) {
        localizationContainer.addModelDecorator(target, keyName, "multilingual");
    };
}

class BaseDirective {
    subscribe(func) {
        this.subscriptionId = MultiLingualData.subscribe(func);
    }
    destroy() {
        MultiLingualData.unsubscribe(this.subscriptionId);
    }
}

class PlaceholderDirective extends BaseDirective {
    constructor(element, name, target) {
        super();
        this.element = element;
        this.name = name;
        this.target = target;
        this.subscribe(this.bind.bind(this));
    }
    bind() {
        var _a;
        var decoratorConfig = localizationContainer.getModelDecorator((_a = this.target) !== null && _a !== void 0 ? _a : this.element.componentName, 'multilingual');
        ;
        if (typeof this.target == "string")
            decoratorConfig = { config: this.target };
        if (decoratorConfig == undefined)
            decoratorConfig = { config: this.element.getAttribute("component-id") };
        if (decoratorConfig) {
            var componentId = decoratorConfig.config;
            var value = MultiLingualData.get(`${componentId}.${this.name}_p`);
            if (value) {
                this.element.placeholder = value;
                this.element.isPopulated = true;
            }
        }
    }
    destroy() {
        super.destroy();
        this.element = undefined;
    }
}

class TextDirective extends BaseDirective {
    constructor(config) {
        super();
        this.config = config;
        this.subscribe(this.bind.bind(this));
    }
    bind() {
        var _a;
        var decoratorConfig = localizationContainer.getModelDecorator((_a = this.config.target) !== null && _a !== void 0 ? _a : this.config.element.componentName, 'multilingual');
        if (typeof this.config.target == "string")
            decoratorConfig = { config: this.config.target };
        if (decoratorConfig == undefined)
            decoratorConfig = { config: this.config.element.getAttribute("component-id") };
        if (decoratorConfig) {
            var componentId = decoratorConfig.config;
            var value = MultiLingualData.get(this.config.text && this.config.text.indexOf("_") != -1 ? `${componentId}.${this.config.text}` : `${componentId}.${this.config.name}_t`);
            if (value) {
                this.textNodeElement = document.createTextNode(value);
                this.config.element.appendChild(this.textNodeElement);
                this.config.element.isPopulated = true;
            }
        }
    }
    destroy() {
        if (this.textNodeElement) {
            this.config.element.removeChild(this.textNodeElement);
        }
        super.destroy();
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { MultiLingualData, PlaceholderDirective, TextDirective, multilingual, BaseDirective as ɵa };
//# sourceMappingURL=rxweb-localization.js.map
